@@ -49,7 +49,6 @@ class TipableVMobject(VMobject):
         "tip_config": {
             "fill_opacity": 1,
             "stroke_width": 0,
-            "tip_style": 0,  # triangle=0, inner_smooth=1, dot=2
         },
         "normal_vector": OUT,
     }
@@ -64,7 +63,6 @@ class TipableVMobject(VMobject):
         tip = self.create_tip(at_start, **kwargs)
         self.reset_endpoints_based_on_tip(tip, at_start)
         self.asign_tip_attr(tip, at_start)
-        tip.set_color(self.get_stroke_color())
         self.add(tip)
         return self
 
@@ -246,7 +244,8 @@ class Arc(TipableVMobject):
         return find_intersection(a1, n1, a2, n2)
 
     def get_start_angle(self):
-        angle = angle_of_vector(self.get_start() - self.get_arc_center())
+        # Fixed dimension error
+        angle = angle_of_vector(self.get_start() - self.get_arc_center().reshape(3))
         return angle % TAU
 
     def get_stop_angle(self):
@@ -788,20 +787,12 @@ class ArrowTip(Triangle):
         "width": DEFAULT_ARROW_TIP_WIDTH,
         "length": DEFAULT_ARROW_TIP_LENGTH,
         "angle": 0,
-        "tip_style": 0,  # triangle=0, inner_smooth=1, dot=2
     }
 
     def __init__(self, **kwargs):
         Triangle.__init__(self, start_angle=0, **kwargs)
         self.set_height(self.width)
         self.set_width(self.length, stretch=True)
-        if self.tip_style == 1:
-            self.set_height(self.length * 0.9, stretch=True)
-            self.data["points"][4] += np.array([0.6 * self.length, 0, 0])
-        elif self.tip_style == 2:
-            h = self.length / 2
-            self.clear_points()
-            self.data["points"] = Dot().set_width(h).get_points()
         self.rotate(self.angle)
 
     def get_base(self):
